{
  inputs = {
    flake-utils.url = "github:numtide/flake-utils";

    nixpkgs.url = "github:nixos/nixpkgs/nixos-unstable";

    pre-commit-hooks.url = "github:cachix/pre-commit-hooks.nix/master";
    pre-commit-hooks.inputs.flake-utils.follows = "flake-utils";
    pre-commit-hooks.inputs.nixpkgs.follows = "nixpkgs";
  };

  outputs = { self, flake-utils, nixpkgs, pre-commit-hooks }: flake-utils.lib.eachDefaultSystem (system:
    let
      pkgs = import nixpkgs { inherit system; };
    in
    {
      checks = {
        pre-commit-check = pre-commit-hooks.lib.${system}.run {
          src = self;
          hooks = {
            black.enable = true;
            nixpkgs-fmt.enable = true;
            shellcheck.enable = true;
          };
        };
      };

      devShells.default = pkgs.mkShell {
        buildInputs = (with pkgs; [
          nixpkgs-fmt
          black
          shellcheck
        ]);

        shellHook = self.checks.${system}.pre-commit-check.shellHook;
      };
    });
}
